#! /bin/bash

#######################
# Check arguments
if [ $# -lt 1 ]
then
    echo "Usage $0 <OpenIDM_home>"
    exit 1
fi

if [ ! -d "$1" ]
then
    echo "$1 must be a directory"
    exit 1
fi
openidm_home=$1

# Get all variables from boot.properties
TEMPFILE=$(mktemp)
grep -v '^#' ${openidm_home}/conf/boot/boot.properties | while read line
do
    if [ "$line" != "" ]
    then
        arg=`echo $line|cut -d '=' -f1|sed 's/\./_/g'`
        val=`echo $line|cut -d '=' -f2-`
        echo $arg=\"$val\" >> $TEMPFILE
    fi
done
source $TEMPFILE
[ $? -ne 0 ] && echo [Failed] && exit 1
rm $TEMPFILE

# Get list of internal users with non-crypted passwords and encrypt each file
TEMPFILE=$(mktemp)
delim=","
sql_request="select CONCAT_WS('${delim}', objectid, pwd) from internaluser where pwd not like '%\$crypto%';"
echo ${sql_request} \
    | mysql --host=${iam_repo_host} --port=${iam_repo_port} --database=${iam_repo_database} --user=${iam_repo_user} \
        --password=${iam_repo_password} --skip-column-names \
    | while read line
do
    user=`echo ${line} | cut -d ${delim} -f1`
    pwd=`echo ${line} | cut -d ${delim} -f2`
    encrypted=`${openidm_home}/cli.sh encrypt $pwd 2>/dev/null | sed -e '1,/BEGIN ENCRYPTED VALUE/d' -e '/END ENCRYPTED VALUE/,$d' | tr '\n' ' ' | sed -e 's/ //g'`
    echo "update internaluser set pwd = '$encrypted' where objectid = '$user';" >> ${TEMPFILE}
done

# execute the UPDATE file
mysql --host=${iam_repo_host} --port=${iam_repo_port} --database=${iam_repo_database} --user=${iam_repo_user} \
        --password=${iam_repo_password} < ${TEMPFILE}

rm ${TEMPFILE}