import org.forgerock.json.resource.NotSupportedException
import org.forgerock.json.resource.CreateRequest
import org.forgerock.json.resource.DeleteRequest
import org.forgerock.json.resource.NotFoundException
import org.slf4j.*;
logger = LoggerFactory.getLogger('logger');

if (request instanceof ActionRequest) {

    login = request.content.getObject().login
    if (login == null) {
            throw new ResourceException(400, "Provide a login");
    }
    type = request.content.getObject().type;
    if (type == null || (type != "compte" && type != "password")) {
            throw new ResourceException(400, "Provide a valid type: 'password' or 'compte'");
    }
    labo = request.content.getObject().labo;
    if (labo == null) {
            throw new ResourceException(400, "Provide a labo");
    }
    group = request.content.getObject().group;
    if (group == null) {
            group = "all";
    }
    // query the system/computing account for login
    accounts = openidm.query("system/computing/account", ["_queryFilter" : "userName eq \"" + login + "\""], ["_id"]).result;
    
    logger.debug("accounts=" + accounts);
    if (accounts.size() == 0) {
            throw new ResourceException(404, "This login does not exist");
    }
 
    // get the owner of the account
    users = openidm.query("repo/link", ["_queryId": "links-for-linkQualifier", "linkType": "openidm2computingaccount", "linkQualifier": login]).result;
    if (users.size() == 0) {
            throw new ResourceException(404, "This login is orphaned");
    }
    if (users.size() > 1) {
            throw new ResourceException(404, "This login is owned by more than 1 identity");
    }


    logger.debug("reading identity: " + users[0].firstId);
    identity = openidm.read("managed/user/" + users[0].firstId);
    if (identity == null) {
            throw new ResourceException(404, "This identity does not exist");
    }

    if (request.action != "add" && request.action != "remove") {
            throw new ResourceException(400, "action not supported, please use 'add' or 'remove'");
    }

    role = openidm.read("managed/role/czar." + type + "." + labo + "." + group, null, ["*","members"]);
    if (role == null) {
            throw new ResourceException(404, "This role does not exist");
    }

	if (request.action == "add") {
                for (member in role.members) {
                  if (member._ref == "managed/user/" + identity._id) {
            		throw new ResourceException(400, "This user already has this role");
                  }
                }
		openidm.patch("managed/role/" + role._id, null,
 			[["operation":"add", "field":"/members/-", "value": ["_ref":"managed/user/" + identity._id] ]]);
		return [result: "ADDED",
                        identity: identity._id,
                        role: role._id
                       ];
	}
	if (request.action == "remove") {
                members = role.members;
                members.removeAll {
                  it._ref == "managed/user/" + identity._id
                }
		openidm.patch("managed/role/" + role._id, null,
                       [["operation": "replace", "field":"/members", "value":members]]);
		return [result: "REMOVED",
                        identity: identity._id,
                        role: role._id
                       ];
	}
} else {
    throw new NotSupportedException(request.getClass().getName());
}

