import org.forgerock.json.resource.NotSupportedException
import org.forgerock.json.resource.ReadRequest
import org.forgerock.json.resource.NotFoundException
import org.slf4j.*;
logger = LoggerFactory.getLogger('logger');

if (request instanceof ReadRequest) {

    login = request.additionalParameters.login;
    if (login == null) {
            throw new ResourceException(404, "Provide a login");
    }
    // query the system/computing account for login
    accounts = openidm.query("system/computing/account", ["_queryFilter" : "userName eq \"" + login + "\""], ["email"]).result;
    
    logger.debug("accounts=" + accounts);
    if (accounts.size() == 0) {
            throw new ResourceException(404, "This login does not exist");
    }
    // do not handle if result.length > 1, it is not possible...
    account = accounts[0];
    // return email if not null
    if (account.email && account.email != "") {
        return ["_id": login, "email": account.email];
    }
 
    // we must get email from identity then

    // get the owner of the account
    users = openidm.query("repo/link", ["_queryId": "links-for-linkQualifier", "linkType": "openidm2computingaccount", "linkQualifier": login]).result;
    if (users.size() == 0) {
            throw new ResourceException(404, "This login is orphaned");
    }
    if (users.size() > 1) {
            throw new ResourceException(404, "This login is owned by more than 1 identity");
    }

    logger.debug("reading identity: " + users[0].firstId);
    identity = openidm.read("managed/user/" + users[0].firstId);
    if (identity == null) {
            throw new ResourceException(404, "This identity does not exist");
    }
    // email is mandatory
    return ["_id": login, "email": identity.mail];
} else {
    throw new NotSupportedException(request.getClass().getName());
}

